.. include:: ../README.rst

.. toctree::
   :maxdepth: 1
   :hidden:

    Getting Started <getting_started/index>
    Benchmarking <benchmarking/index>
    Examples <examples/index>
    API Reference <_apidoc/modules>

Indices and tables
__________________

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
